package org.jtheque.movies.controllers.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.movies.controllers.able.IMovieController;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.services.able.IMoviesService;
import org.jtheque.movies.views.able.IMovieView;
import org.jtheque.movies.views.impl.models.MoviesModel;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.impl.PrincipalController;
import org.jtheque.primary.view.impl.models.tree.Element;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.tree.TreePath;

import java.util.List;

/**
 * The Swing controller for the film view.
 *
 * @author Baptiste Wicht
 */
public final class MovieController extends PrincipalController implements IMovieController {
    @Resource
    private IMovieView movieView;

    @Override
    public IMovieView getView() {
        return movieView;
    }

    @PostConstruct
    public void init() {
        setState(getViewState());
    }

    @Override
    public void valueChanged(TreeSelectionEvent event) {
        TreePath current = ((JTree) event.getSource()).getSelectionPath();

        if (current != null && current.getLastPathComponent() instanceof Element) {
            MovieImpl movie = (MovieImpl) current.getLastPathComponent();

            if (movie != null) {
                view(movie);
            }
        }
    }

    @Override
    public void save() {
        ControllerState newState = getState().save(movieView.fillFilmFormBean());

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public MoviesModel getViewModel() {
        return (MoviesModel) movieView.getModel();
    }

    @Override
    public void view(MovieImpl movie) {
        ControllerState newState = getState().view(movie);

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void manualEdit() {
        ControllerState newState = getState().manualEdit();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void createMovie() {
        ControllerState newState = getState().create();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void deleteCurrentMovie() {
        ControllerState newState = getState().delete();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void cancel() {
        ControllerState newState = getState().cancel();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public String getDataType() {
        return IMoviesService.DATA_TYPE;
    }

    @Override
    public List<MovieImpl> getDisplayList() {
        return getViewModel().getDisplayList();
    }
}