package org.jtheque.movies.controllers.impl.states;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.movies.controllers.able.IMovieController;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.services.able.IMoviesService;
import org.jtheque.movies.views.impl.edits.create.CreatedMovieEdit;
import org.jtheque.movies.views.impl.fb.MovieFormBean;
import org.jtheque.movies.views.impl.models.MoviesModel;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.view.able.ViewMode;

import javax.annotation.Resource;

/**
 * A state of film view correspond with a creation.
 *
 * @author Baptiste Wicht
 */
public final class NewMovieState implements ControllerState {
    @Resource
    private IMovieController controller;

    @Resource
    private IMoviesService moviesService;

    @Override
    public MoviesModel getViewModel() {
        return controller.getViewModel();
    }

    @Override
    public void apply() {
        getViewModel().setCurrentMovie(moviesService.getEmptyMovie());
        getViewModel().setEnabled(true);
        controller.getView().getToolbarView().setDisplayMode(ViewMode.NEW);
    }

    @Override
    public ControllerState save(FormBean bean) {
        MovieFormBean infos = (MovieFormBean) bean;

        MovieImpl movie = new MovieImpl();

        //On complte les donnes du movie avec les donnes de cette interface
        movie.setTitle(infos.getTitle());
        movie.setCategories(infos.getCategories());
        movie.setNote(infos.getNote());
        movie.setFile(infos.getFile());

        //On cre le film
        moviesService.create(movie);

        Managers.getManager(IUndoRedoManager.class).addEdit(new CreatedMovieEdit(movie));

        controller.getView().resort();

        return controller.getViewState();
    }

    @Override
    public ControllerState cancel() {
        ControllerState nextState = null;

        controller.getView().selectFirst();

        if (moviesService.getMovies().size() <= 0) {
            nextState = controller.getViewState();
        }

        return nextState;
    }

    @Override
    public ControllerState create() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState manualEdit() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState delete() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState autoEdit(Data data) {
        switchMovie(data);

        return controller.getAutoAddState();
    }

    @Override
    public ControllerState view(Data data) {
        switchMovie(data);

        return controller.getViewState();
    }

    /**
     * Switch the current movie.
     *
     * @param data The new movie to display. 
     */
    private void switchMovie(Data data){
        MovieImpl movie = (MovieImpl) data;

        if (Managers.getManager(IViewManager.class).askI18nUserForConfirmation(
                "movie.dialogs.confirmSave",
                "movie.dialogs.confirmSave.title")) {
            controller.save();
        }

        getViewModel().setCurrentMovie(movie);
    }
}