package org.jtheque.movies.persistence.od;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.resource.IResourceManager;
import org.jtheque.core.managers.resource.ImageType;
import org.jtheque.core.managers.properties.IPropertiesManager;
import org.jtheque.movies.MoviesModule;
import org.jtheque.movies.persistence.od.abstraction.Movie;
import org.jtheque.utils.EqualsUtils;

import javax.swing.Icon;

/**
 * A movie implementation.
 *
 * @author Baptiste Wicht
 */
public final class MovieImpl extends Movie {
    private MovieImpl memento;
    private boolean mementoState;

    @Override
    public String getAffichableText() {
        return getTitle();
    }

    @Override
    public int hashCode() {
        return Managers.getManager(IPropertiesManager.class).hashCode(this);
    }

    @Override
    public Icon getIcon() {
        return Managers.getManager(IResourceManager.class).getIcon(MoviesModule.IMAGES_BASENAME, "film", ImageType.PNG);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if(EqualsUtils.areObjectIncompatible(this, obj)){
            return false;
        }

        final Movie other = (Movie) obj;
        
        if(EqualsUtils.areNotEquals(getTitle(), other.getTitle())){
            return false;
        }
        
        if(EqualsUtils.areNotEquals(getCategories(), other.getCategories())){
            return false;
        }
        
        if(EqualsUtils.areNotEquals(getFile(), other.getFile())){
            return false;
        }

        return !EqualsUtils.areNotEquals(getNote(), other.getNote());

    }

    @Override
    public void saveToMemento() {
        mementoState = true;

        memento = Managers.getManager(IPropertiesManager.class).createMemento(this);

        if (memento == null) {
            mementoState = false;
        }
    }

    @Override
    public void restoreMemento() {
        if (mementoState) {
            Managers.getManager(IPropertiesManager.class).restoreMemento(this, memento);
        }
    }
}