package org.jtheque.movies.persistence.od.abstraction;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.od.CollectionImpl;

import java.util.ArrayList;
import java.util.List;

/**
 * A movie.
 *
 * @author Baptiste Wicht
 */
public abstract class Movie extends Data {
    private String title;
    private List<CategoryImpl> categories = new ArrayList<CategoryImpl>(6);
    private String file;
    private Note note;
    private CollectionImpl theCollection;

    /**
     * Return the collection.
     *
     * @return The collection.
     */
    public final CollectionImpl getTheCollection() {
        return theCollection;
    }

    /**
     * Set the collection of the movie.
     *
     * @param theCollection The collection of the movie.
     */
    public final void setTheCollection(CollectionImpl theCollection) {
        this.theCollection = theCollection;
    }

    /**
     * Return the title.
     *
     * @return The title.
     */
    public final String getTitle() {
        return title;
    }

    /**
     * Set the title.
     *
     * @param title The title.
     */
    public final void setTitle(String title) {
        this.title = title;
    }

    /**
     * Return the categories of the movie.
     *
     * @return The categories of the movie.
     */
    public final List<CategoryImpl> getCategories() {
        return categories;
    }

    /**
     * Set the categories of the movie.
     *
     * @param categories The catgories of the movie.
     */
    public final void setCategories(List<CategoryImpl> categories) {
        this.categories = new ArrayList<CategoryImpl>(categories);
    }

    /**
     * Return the path to the file.
     *
     * @return The path to the file.
     */
    public final String getFile() {
        return file;
    }

    /**
     * Set the path to the file.
     *
     * @param file The path to the file.
     */
    public final void setFile(String file) {
        this.file = file;
    }

    /**
     * Return the note of the movie.
     *
     * @return The note of the movie.
     */
    public final Note getNote() {
        return note;
    }

    /**
     * Set the note of the movie.
     *
     * @param note The note of the movie.
     */
    public final void setNote(Note note) {
        this.note = note;
    }
}