package org.jtheque.movies.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.core.managers.persistence.able.AbstractDataContainer;
import org.jtheque.movies.persistence.dao.able.IDaoMovies;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.services.able.IMoviesService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * A service for movies implementation.
 *
 * @author Baptiste Wicht
 */
@Service
public final class MoviesService extends AbstractDataContainer<MovieImpl> implements IMoviesService {
    @Resource
    private IDaoMovies daoMovies;

    @Override
    public MovieImpl getEmptyMovie() {
        MovieImpl movie = new MovieImpl();

        movie.setTitle(Managers.getManager(ILanguageManager.class).getMessage("values.new"));

        return movie;
    }

    @Override
    public List<MovieImpl> getMovies() {
        return daoMovies.getMovies();
    }

    @Override
    @Transactional
    public boolean delete(MovieImpl movie) {
        return daoMovies.delete(movie);
    }

    @Override
    @Transactional
    public void save(MovieImpl movie) {
        daoMovies.save(movie);
    }

    @Override
    @Transactional
    public void create(MovieImpl movie) {
        daoMovies.create(movie);
    }

    @Override
    @Transactional
    public void saveAll() {
        daoMovies.saveAll();
    }

    @Override
    public List<MovieImpl> getAllMovies() {
        return daoMovies.getAllMovies();
    }

    @Override
    public List<MovieImpl> getDatas() {
        return daoMovies.getMovies();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoMovies.addDataListener(listener);
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }

    @Override
    @Transactional
    public void clearAll() {
        daoMovies.clearAll();
    }
}