package org.jtheque.movies.views.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.views.impl.fb.MovieFormBean;

import javax.swing.DefaultListModel;
import java.util.List;
import java.awt.Component;

/**
 * A categories view specification.
 *
 * @author Baptiste Wicht
 */
public interface ICategoriesView {
    /**
     * Cette mthode remplit le film avec les donnes de l'interface.
     *
     * @param fb Le film dont il faut remplir les donnes
     */
    void fillFilm(MovieFormBean fb);

    /**
     * Set the enabled state of the view.
     *
     * @param enabled true if the state has to be enabled else false.
     */
    void setEnabled(boolean enabled);

    /**
     * Return the model of the list of actors.
     *
     * @return The <code>CategoriesListModel</code> associated to the list of actors.
     */
    DefaultListModel getCategoriesModel();

    /**
     * Return the actors for film model.
     *
     * @return The actors for film model.
     */
    DefaultListModel getCategoriesForMovieModel();

    /**
     * Return the indices of the selected actors.
     *
     * @return An array containing the indices of the selected actors.
     */
    int[] getSelectedActorsIndices();

    /**
     * Return the indices of the selected actors for film.
     *
     * @return An array containing the indices of the selected actors for film.
     */
    int[] getSelectedActorsForFilmIndices();

    /**
     * Reload the view with an another movie.
     *
     * @param movie The new current movie.
     */
    void reload(MovieImpl movie);

    /**
     * Validate the panel.
     *
     * @param errors The errors to fill.
     */
    void validate(List<JThequeError> errors);
    
    Component getImpl();
}
