package org.jtheque.movies.views.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.ValidationUtils;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.impl.components.InfiniteWaitFigure;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.movies.views.able.ICategoryView;
import org.jtheque.movies.views.impl.models.CategoryModel;
import org.jtheque.primary.od.abstraction.Data;

import javax.swing.JFrame;
import javax.swing.JTextField;
import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * Cette classe est la classe d'interface graphique permettant d'ajouter ou de modifier un genre.
 *
 * @author Baptiste Wicht
 */
public final class CategoryView extends SwingDialogView implements ICategoryView {
    private static final long serialVersionUID = -3525319522701158262L;
    
    private JTextField fieldName;

    private JThequeAction saveAction;
    private JThequeAction cancelAction;
    
    /**
     * Construct a new Category View. 
     * 
     * @param parent The parent frame. 
     */
    public CategoryView(Frame parent) {
        super(parent);
    }

    @Override
    public void reload() {
        //On modifie le titre
        setTitleKey("category.view.title");

        getModel().setCategory(null);

        /* Vidage des composants graphiques */
        fieldName.setText("");
    }
    
    @Override
    public void reload(Data data) {
        CategoryImpl category = (CategoryImpl) data;

        getModel().setCategory(category);

        //On modifie le titre
        setTitle(Managers.getManager(ILanguageManager.class).getMessage("category.view.title.modify") +
                category.getAffichableText());

        /* Remplissage des champs */
        fieldName.setText(category.getTitle());
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
        setIconImage(getDefaultWindowIcon());
        setWaitFigure(new InfiniteWaitFigure());
        pack();

        SwingUtils.centerFrame(this);
        
        reload();
    }

    /**
     * Cette mthode initialise et retourne le contentPane de la fentre.
     *
     * @return Le contentPane
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();

        builder.addI18nLabel("category.view.name", builder.gbcSet(0, 0));
        
        fieldName = builder.add(new JTextField(15), builder.gbcSet(1, 0));
        SwingUtils.addFieldValidateAction(fieldName, saveAction);
        SwingUtils.addFieldLenghtLimit(fieldName, 50);
        
        builder.addButtonBar(builder.gbcSet(0, 1, GridBagUtils.HORIZONTAL, 2, 1), saveAction, cancelAction);

        return builder.getPanel();
    }

    @Override
    public JTextField getFieldName() {
        return fieldName;
    }

    @Override
    public CategoryModel getModel() {
        return (CategoryModel) super.getModel();
    }

    @Override
    public void refreshText() {
        super.refreshText();

        if (getModel().getCategory() != null) {
            setTitle(Managers.getManager(ILanguageManager.class).getMessage("kind.view.title.modify") +
                    getModel().getCategory().getAffichableText());
        }
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        ValidationUtils.rejectIfEmpty(fieldName.getText(), "kind.view.name", errors);
        ValidationUtils.rejectIfLongerThan(fieldName.getText(), "kind.view.name", 150, errors);
    }

    public void setSaveAction(JThequeAction saveAction) {
        this.saveAction = saveAction;
    }

    public void setCancelAction(JThequeAction cancelAction) {
        this.cancelAction = cancelAction;
    }
}