package org.jtheque.movies.views.impl.choiceActions;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.services.able.ICategoriesService;
import org.jtheque.movies.services.able.IMoviesService;
import org.jtheque.movies.views.impl.edits.delete.DeletedCategoryEdit;
import org.jtheque.movies.views.impl.edits.delete.DeletedMovieEdit;
import org.jtheque.primary.view.impl.choice.AbstractChoiceAction;

import javax.annotation.Resource;

/**
 * An action to delete the selected item.
 *
 * @author Baptiste Wicht
 */
public final class DeleteChoiceAction extends AbstractChoiceAction {
    @Resource
    private IMoviesService moviesService;

    @Resource
    private ICategoriesService categoriesService;

    /* Singletons */
    private final ILanguageManager resources = Managers.getManager(ILanguageManager.class);

    @Override
    public boolean canDoAction(final String action) {
        return "delete".equals(action);
    }

    @Override
    public void execute() {
        final boolean yes = Managers.getManager(IViewManager.class).askUserForConfirmation(
                resources.getMessage("choice.dialogs.delete") + ' ' + getSelectedItem().toString(),
                resources.getMessage("choice.dialogs.delete.title"));

        if (yes) {
            delete();
        }
    }

    /**
     * Delete the selected item.
     */
    private void delete() {
        if (IMoviesService.DATA_TYPE.equals(getContent())) {
            boolean deleted = moviesService.delete((MovieImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedMovieEdit((MovieImpl) getSelectedItem()));
            }
        } else if (ICategoriesService.DATA_TYPE.equals(getContent())) {
            boolean deleted = categoriesService.delete((CategoryImpl) getSelectedItem());

            if (deleted) {
                Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedCategoryEdit((CategoryImpl) getSelectedItem()));
            }
        }
    }
}