package org.jtheque.movies.views.impl.fb;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.primary.controller.able.FormBean;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Baptiste Wicht
 */
public final class MovieFormBean implements FormBean {
    private String title;
    private List<CategoryImpl> categories = new ArrayList<CategoryImpl>(6);
    private String file;
    private Note note;

    /**
     * Return the title.
     *
     * @return The title.
     */
    public String getTitle() {
        return title;
    }

    /**
     * Set the title.
     *
     * @param title The title.
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * Return the categories of the movie.
     *
     * @return The categories of the movie.
     */
    public List<CategoryImpl> getCategories() {
        return categories;
    }

    /**
     * Set the categories of the movie.
     *
     * @param categories The catgories of the movie.
     */
    public void setCategories(List<CategoryImpl> categories) {
        this.categories = new ArrayList<CategoryImpl>(categories);
    }

    /**
     * Return the path to the file.
     *
     * @return The path to the file.
     */
    public String getFile() {
        return file;
    }

    /**
     * Set the path to the file.
     *
     * @param file The path to the file.
     */
    public void setFile(String file) {
        this.file = file;
    }

    /**
     * Return the note of the movie.
     *
     * @return The note of the movie.
     */
    public Note getNote() {
        return note;
    }

    /**
     * Set the note of the movie.
     *
     * @param note The note of the movie.
     */
    public void setNote(Note note) {
        this.note = note;
    }

    @Override
    public String toString() {
        return "MovieFormBean{" +
                "title='" + title + '\'' +
                ", categories=" + categories +
                ", file='" + file + '\'' +
                ", note=" + note +
                '}';
    }
}