package org.jtheque.movies.views.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.movies.persistence.od.CategoryImpl;

import javax.swing.DefaultListModel;
import java.util.ArrayList;
import java.util.List;

/**
 * A simple model for actors.
 *
 * @author Baptiste Wicht
 */
public final class SimpleCategoriesModel extends DefaultListModel {
    private static final long serialVersionUID = 627034111249354845L;

    private final List<CategoryImpl> categories;

    /**
     * Construct a new SimpleActorsModel.
     */
    public SimpleCategoriesModel() {
        super();

        categories = new ArrayList<CategoryImpl>(6);
    }

    @Override
    public Object getElementAt(int index) {
        return categories.get(index);
    }

    @Override
    public Object get(int index) {
        return categories.get(index);
    }

    @Override
    public int getSize() {
        return categories.size();
    }

    @Override
    public Object remove(int index) {
        CategoryImpl category = categories.remove(index);
        fireIntervalRemoved(this, index, index);
        return category;
    }

    @Override
    public void addElement(Object obj) {
        categories.add((CategoryImpl) obj);
        fireIntervalAdded(this, getSize(), getSize());
    }

    @Override
    public void removeAllElements() {
        categories.clear();
        fireContentsChanged(this, 0, getSize());
    }

    @Override
    public boolean removeElement(Object obj) {
        int index = categories.indexOf(obj);
        boolean remove = categories.remove(obj);
        fireIntervalRemoved(this, index, index);
        return remove;
    }

    /**
     * Return the categories.
     *
     * @return A List containing all the categories of the model.
     */
    public List<CategoryImpl> getCategories() {
        return categories;
    }
}