package org.jtheque.movies.views.impl.panel;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXPanel;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeSimpleAction;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.ValidationUtils;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.views.able.ICategoriesView;
import org.jtheque.movies.views.impl.fb.MovieFormBean;
import org.jtheque.movies.views.impl.models.CategoriesListModel;
import org.jtheque.movies.views.impl.models.SimpleCategoriesModel;
import org.jtheque.utils.ui.GridBagUtils;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.ListSelectionModel;
import javax.annotation.PostConstruct;

import java.util.List;
import java.awt.Component;

/**
 * A panel to display the categories of a movie and enable the user to edit them. 
 * 
 * @author Baptiste Wicht
 */
public final class JPanelCategories extends JXPanel implements ICategoriesView {
    private static final long serialVersionUID = 447863972139498415L;

    private JButton buttonAdd;
    private JButton buttonRemove;
    private JButton buttonNew;
    private JList listCategories;
    private JList listCategoriesForFilm;
    
    private CategoriesListModel categoriesModel;
    private SimpleCategoriesModel categoriesForMovieModel;
    
    private JThequeSimpleAction removeAction;
    private JThequeSimpleAction addAction;
    private JThequeAction newAction;

    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);
    
        categoriesModel = new CategoriesListModel();
        
        listCategories = builder.addList(categoriesModel, null, builder.gbcSet(0, 0, GridBagUtils.BOTH, 1, 3));
        listCategories.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);

        categoriesForMovieModel = new SimpleCategoriesModel();
        
        listCategoriesForFilm = builder.addList(categoriesForMovieModel, null, builder.gbcSet(2, 0, GridBagUtils.BOTH, 1, 3));
        listCategoriesForFilm.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        
        buttonAdd = builder.addButton(addAction, builder.gbcSet(1, 0));
        buttonAdd.setEnabled(false);

        buttonRemove = builder.addButton(removeAction, builder.gbcSet(1, 1));
        buttonRemove.setEnabled(false);

        buttonNew = builder.addButton(newAction, builder.gbcSet(1, 2));
        buttonNew.setEnabled(false);
    }

    @Override
    public void fillFilm(MovieFormBean fb) {
        if (categoriesForMovieModel.getSize() != 0) {
            fb.setCategories(categoriesForMovieModel.getCategories());
        }
    }

    @Override
    public void setEnabled(boolean enabled) {
        buttonAdd.setEnabled(enabled);
        buttonRemove.setEnabled(enabled);
        buttonNew.setEnabled(enabled);

        super.setEnabled(enabled);
    }

    @Override
    public DefaultListModel getCategoriesModel() {
        return categoriesModel;
    }

    @Override
    public DefaultListModel getCategoriesForMovieModel() {
        return categoriesForMovieModel;
    }

    @Override
    public int[] getSelectedActorsIndices() {
        return listCategories.getSelectedIndices();
    }

    @Override
    public int[] getSelectedActorsForFilmIndices() {
        return listCategoriesForFilm.getSelectedIndices();
    }

    @Override
    public void reload(MovieImpl movie) {
        categoriesForMovieModel.removeAllElements();
        categoriesModel.reload();

        List<CategoryImpl> categories = movie.getCategories();

        for (CategoryImpl category : categories) {
            categoriesModel.removeElement(category);
            categoriesForMovieModel.addElement(category);
        }
    }

    @Override
    public void validate(List<JThequeError> errors) {
        ValidationUtils.rejectIfEmpty(listCategoriesForFilm, "movie.categories", errors);
    }

    @Override
    public Component getImpl() {
        return this;
    }

    public void setRemoveAction(JThequeSimpleAction removeAction) {
        this.removeAction = removeAction;
    }

    public void setAddAction(JThequeSimpleAction addAction) {
        this.addAction = addAction;
    }

    public void setNewAction(JThequeAction newAction) {
        this.newAction = newAction;
    }
}