package org.jtheque.movies.views.impl.sort;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.movies.persistence.od.CategoryImpl;
import org.jtheque.movies.persistence.od.MovieImpl;
import org.jtheque.movies.services.able.IMoviesService;
import org.jtheque.primary.view.impl.models.tree.Category;
import org.jtheque.primary.view.impl.models.tree.JThequeTreeModel;
import org.jtheque.primary.view.impl.models.tree.RootElement;
import org.jtheque.primary.view.impl.sort.Sorter;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Baptiste Wicht
 */
public final class ByCategorySorter implements Sorter {
    @Resource
    private IMoviesService moviesService;

    @Override
    public boolean canSort(final String content, final String sortType) {
        return IMoviesService.SORT_BY_CATEGORY.equals(sortType);
    }

    @Override
    public void sort(JThequeTreeModel model) {
        RootElement root = model.getRoot();

        CategoryImpl noCategory = new CategoryImpl();
        noCategory.setTitle("...");
        
        List<CategoryImpl> groups = new ArrayList<CategoryImpl>(10);
        List<MovieImpl> movies = moviesService.getMovies();

        for (MovieImpl movie : movies) {
            if(movie.getCategories().isEmpty()){
                if (!groups.contains(noCategory)) {
                    root.addCategory(new Category(noCategory.getElementName()));
                    groups.add(noCategory);
                }
                
                int index = groups.indexOf(noCategory);
    
                root.getCategory(index).addElement(movie);
            } else {
                for (CategoryImpl category : movie.getCategories()) {
                    if (!groups.contains(category)) {
                        root.addCategory(new Category(category.getElementName()));
                        groups.add(category);
                    }
    
                    int index = groups.indexOf(category);
    
                    root.getCategory(index).addElement(movie);
                }
            }
        }

        model.setRootElement(root);
    }
}